@@ -8,15 +8,7 @@
 #
 ################################################################################
 #
-# $Project: /Convert-Binary-C $
-# $Author: mhx $
-# $Date: 2011/04/10 14:44:54 +0200 $
-# $Revision: 38 $
-# $Source: /lib/Convert/Binary/C/Cached.pm $
-#
-################################################################################
-#
-# Copyright (c) 2002-2011 Marcus Holland-Moritz. All rights reserved.
+# Copyright (c) 2002-2020 Marcus Holland-Moritz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -31,8 +23,7 @@ use vars qw( @ISA $VERSION );
 
 @ISA = qw(Convert::Binary::C);
 
-$VERSION = do { my @r = '$Snapshot: /Convert-Binary-C/0.75 $' =~ /(\d+\.\d+(?:_\d+)?)/; @r ? $r[0] : '9.99' };
-$VERSION = eval $VERSION;
+$VERSION = '0.80';
 
 sub new
 {
@@ -236,7 +227,7 @@ sub __parse
 sub __can_use_cache
 {
   my $self = shift;
-  my $fh = new IO::File;
+  my $fh = IO::File->new;
 
   unless (-e $self->{cache} and -s _) {
     $ENV{CBCC_DEBUG} and print STDERR "CBCC: cache file '$self->{cache}' doesn't exist or is empty\n";
@@ -313,7 +304,7 @@ sub __can_use_cache
 sub __save_cache
 {
   my $self = shift;
-  my $fh = new IO::File;
+  my $fh = IO::File->new;
 
   $fh->open(">$self->{cache}") or croak "Cannot open '$self->{cache}': $!";
 
@@ -375,8 +366,8 @@ Convert::Binary::C::Cached - Caching for Convert::Binary::C
   $c = Convert::Binary::C::Cached->new(
          Cache   => '/tmp/cache.c',
          Include => [
-           '/usr/lib/gcc/i686-pc-linux-gnu/4.5.2/include',
-           '/usr/lib/gcc/i686-pc-linux-gnu/4.5.2/include-fixed',
+           '/usr/lib/gcc/x86_64-pc-linux-gnu/10.2.0/include',
+           '/usr/lib/gcc/x86_64-pc-linux-gnu/10.2.0/include-fixed',
            '/usr/include',
          ],
        );
@@ -447,7 +438,7 @@ algorithm cannot detect that an update is required.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002-2011 Marcus Holland-Moritz. All rights reserved.
+Copyright (c) 2002-2020 Marcus Holland-Moritz. All rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
@@ -456,4 +447,3 @@ it under the same terms as Perl itself.
 See L<Convert::Binary::C>.
 
 =cut
-
